#!/bin/bash

echo "Inside ovf-file-preparation script"

POST_SCRIPT_COMPLETION=$PWD
INITIAL_PATH=/usr/share/nginx/html/repo/svm/

cd $INITIAL_PATH

FILE_PATH="./availableVersions"
# DOWNLOAD_URLS_FILE is defined in API path. Do not modify without client side changes in Mps Post Install (SVM Registration)
DOWNLOAD_URLS_FILE="./file-download-urls"

# File used to store the urls of ovf hosted inside the ui pod
touch $DOWNLOAD_URLS_FILE

for BUILD_NUMBER in `cat $FILE_PATH`
do
    BASE_BUILDWEB_URL="http://build-squid.eng.vmware.com/build/mts/release/bora-$BUILD_NUMBER/publish/exports/ovf/"
    # Get the directory listing of this particular ob build
    echo "Downloading files for build number: $BUILD_NUMBER"
    # This link only works for ob builds of svm appliance. To test an sb build, follow the steps mentioned in the cnfluence page
    # https://confluence.eng.vmware.com/display/NSBU/SVM+Ovf+Hosting+on+NAPP
    wget $BASE_BUILDWEB_URL -O htmlfile

    # Extract the release version and build number for directory construction and create new directory
    for FILE_NAME in `cat htmlfile | grep nsx-svm-appliance | awk -F'"' '{print $2}' | awk -F'-' '{print $4}'`
    do
        if [ ${FILE_NAME: -3} = "ovf" ]; then
            # Get the complete release version. Ex: 4.2.0.0.0.23229412
            RELEASE_VERSION=${FILE_NAME%.ovf}
            mkdir -p $RELEASE_VERSION/ovf/
            # Change the download location to newly created directory
            DOWNLOAD_DIRECTORY="$INITIAL_PATH$RELEASE_VERSION/ovf/"
        fi
    done

    # Get the filenames one by one and download the files
    for URL in `cat htmlfile | grep nsx-svm-appliance | awk -F'"' '{print $2}'`
    do
        # Save the download url on encountering the ovf file
        if [ ${URL: -3} = "ovf" ]; then
            echo /napp/api/v1/malware-prevention/repo/svm/$RELEASE_VERSION/ovf/$URL >> $DOWNLOAD_URLS_FILE
        fi
        echo "Downloading: $URL"
        # wget the file from build web
        wget $BASE_BUILDWEB_URL$URL -P $DOWNLOAD_DIRECTORY
    done

    # Remove the file to avoid issues with next build number ovf file download
    rm htmlfile
done

# Remove the file containing the ob build numbers
rm $FILE_PATH

# Return to the original directory
cd $POST_SCRIPT_COMPLETION